@@ -19,10 +19,16 @@
 /*! \file
  *
  * \brief Connect to festival
+ *
+ * \author Christos Ricudis <ricudis@itc.auth.gr>
  * 
  * \ingroup applications
  */
 
+#include "asterisk.h"
+
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 65853 $")
+
 #include <sys/types.h>
 #include <stdlib.h>
 #include <unistd.h>
@@ -40,10 +46,6 @@
 #include <fcntl.h>
 #include <ctype.h>
 
-#include "asterisk.h"
-
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 48374 $")
-
 #include "asterisk/file.h"
 #include "asterisk/logger.h"
 #include "asterisk/channel.h"
@@ -57,8 +59,6 @@ ASTERISK_FILE_VERSION(__FILE__, "$Revision: 48374 $")
 
 #define FESTIVAL_CONFIG "festival.conf"
 
-static char *tdesc = "Simple Festival Interface";
-
 static char *app = "Festival";
 
 static char *synopsis = "Say text to the user";
@@ -68,9 +68,6 @@ static char *descrip =
 "play it to the user, allowing any given interrupt keys to immediately terminate and return\n"
 "the value, or 'any' to allow any number back (useful in dialplan)\n";
 
-STANDARD_LOCAL_USER;
-
-LOCAL_USER_DECL;
 
 static char *socket_receive_file_to_buff(int fd,int *size)
 {
@@ -85,7 +82,10 @@ static char *socket_receive_file_to_buff(int fd,int *size)
     char c;
 
     bufflen = 1024;
-    buff = (char *)malloc(bufflen);
+    if (!(buff = ast_malloc(bufflen)))
+    {
+        /* TODO: Handle memory allocation failure */
+    }
     *size=0;
 
     for (k=0; file_stuff_key[k] != '\0';)
@@ -95,7 +95,10 @@ static char *socket_receive_file_to_buff(int fd,int *size)
         if ((*size)+k+1 >= bufflen)
         {   /* +1 so you can add a NULL if you want */
             bufflen += bufflen/4;
-            buff = (char *)realloc(buff,bufflen);
+            if (!(buff = ast_realloc(buff, bufflen)))
+            {
+                /* TODO: Handle memory allocation failure */
+            }
         }
         if (file_stuff_key[k] == c)
             k++;
@@ -143,7 +146,7 @@ static int send_waveform_to_fd(char *waveform, int length, int fd) {
                 if (x != fd)
                         close(x);
         }
-	if (option_highpriority)
+	if (ast_opt_high_priority)
 		ast_set_priority(0);
 	signal(SIGPIPE, SIG_DFL);
 	pthread_sigmask(SIG_UNBLOCK, &fullset, NULL);
@@ -175,7 +178,9 @@ static int send_waveform_to_channel(struct ast_channel *chan, char *waveform, in
 		struct ast_frame f;
 		char offset[AST_FRIENDLY_OFFSET];
 		char frdata[2048];
-	} myf;
+	} myf = {
+		.f = { 0, },
+	};
 	
         if (pipe(fds)) {
                  ast_log(LOG_WARNING, "Unable to create pipe\n");
@@ -235,7 +240,6 @@ static int send_waveform_to_channel(struct ast_channel *chan, char *waveform, in
 					myf.f.subclass = AST_FORMAT_SLINEAR;
 					myf.f.datalen = res;
 					myf.f.samples = res / 2;
-					myf.f.mallocd = 0;
 					myf.f.offset = AST_FRIENDLY_OFFSET;
 					myf.f.src = __PRETTY_FUNCTION__;
 					myf.f.data = myf.frdata;
@@ -278,16 +282,16 @@ static int festival_exec(struct ast_channel *chan, void *vdata)
 {
 	int usecache;
 	int res=0;
-	struct localuser *u;
+	struct ast_module_user *u;
  	struct sockaddr_in serv_addr;
 	struct hostent *serverhost;
 	struct ast_hostent ahp;
 	int fd;
 	FILE *fs;
-	char *host;
-	char *cachedir;
-	char *temp;
-	char *festivalcommand;
+	const char *host;
+	const char *cachedir;
+	const char *temp;
+	const char *festivalcommand;
 	int port=1314;
 	int n;
 	char ack[4];
@@ -310,18 +314,19 @@ static int festival_exec(struct ast_channel *chan, void *vdata)
 	char *data;	
 	char *intstr;
 	struct ast_config *cfg;
+	char *newfestivalcommand;
 
 	if (ast_strlen_zero(vdata)) {
 		ast_log(LOG_WARNING, "festival requires an argument (text)\n");
 		return -1;
 	}
 
-	LOCAL_USER_ADD(u);
+	u = ast_module_user_add(chan);
 
 	cfg = ast_config_load(FESTIVAL_CONFIG);
 	if (!cfg) {
 		ast_log(LOG_WARNING, "No such configuration file %s\n", FESTIVAL_CONFIG);
-		LOCAL_USER_REMOVE(u);
+		ast_module_user_remove(u);
 		return -1;
 	}
 	if (!(host = ast_variable_retrieve(cfg, "general", "host"))) {
@@ -342,15 +347,25 @@ static int festival_exec(struct ast_channel *chan, void *vdata)
 	}
 	if (!(festivalcommand = ast_variable_retrieve(cfg, "general", "festivalcommand"))) {
 		festivalcommand = "(tts_textasterisk \"%s\" 'file)(quit)\n";
+	} else { /* This else parses the festivalcommand that we're sent from the config file for \n's, etc */
+		int i, j;
+		newfestivalcommand = alloca(strlen(festivalcommand) + 1);
+
+		for (i = 0, j = 0; i < strlen(festivalcommand); i++) {
+			if (festivalcommand[i] == '\\' && festivalcommand[i + 1] == 'n') {
+				newfestivalcommand[j++] = '\n';
+				i++;
+			} else if (festivalcommand[i] == '\\') {
+				newfestivalcommand[j++] = festivalcommand[i + 1];
+				i++;
+			} else
+				newfestivalcommand[j++] = festivalcommand[i];
+		}
+		newfestivalcommand[j] = '\0';
+		festivalcommand = newfestivalcommand;
 	}
 	
 	data = ast_strdupa(vdata);
-	if (!data) {
-		ast_log(LOG_ERROR, "Out of memery\n");
-		ast_config_destroy(cfg);
-		LOCAL_USER_REMOVE(u);
-		return -1;
-	}
 
 	intstr = strchr(data, '|');
 	if (intstr) {	
@@ -368,7 +383,7 @@ static int festival_exec(struct ast_channel *chan, void *vdata)
     	if (fd < 0) {
 		ast_log(LOG_WARNING,"festival_client: can't get socket\n");
 		ast_config_destroy(cfg);
-		LOCAL_USER_REMOVE(u);
+		ast_module_user_remove(u);
         	return -1;
 	}
         memset(&serv_addr, 0, sizeof(serv_addr));
@@ -378,7 +393,7 @@ static int festival_exec(struct ast_channel *chan, void *vdata)
 	        if (serverhost == (struct hostent *)0) {
         	    	ast_log(LOG_WARNING,"festival_client: gethostbyname failed\n");
 			ast_config_destroy(cfg);
-			LOCAL_USER_REMOVE(u);
+			ast_module_user_remove(u);
 	            	return -1;
         	}
 	        memmove(&serv_addr.sin_addr,serverhost->h_addr, serverhost->h_length);
@@ -389,7 +404,7 @@ static int festival_exec(struct ast_channel *chan, void *vdata)
 	if (connect(fd, (struct sockaddr *)&serv_addr, sizeof(serv_addr)) != 0) {
 		ast_log(LOG_WARNING,"festival_client: connect to server failed\n");
 		ast_config_destroy(cfg);
-		LOCAL_USER_REMOVE(u);
+		ast_module_user_remove(u);
         	return -1;
     	}
     	
@@ -481,7 +496,7 @@ static int festival_exec(struct ast_channel *chan, void *vdata)
                                ast_log(LOG_WARNING,"Unable to read from cache/festival fd\n");
 			       close(fd);
 			       ast_config_destroy(cfg);
-			       LOCAL_USER_REMOVE(u);
+			       ast_module_user_remove(u);
                                return -1;
                        }
                        n += read_data;
@@ -508,41 +523,31 @@ static int festival_exec(struct ast_channel *chan, void *vdata)
 	} while (strcmp(ack,"OK\n") != 0);
 	close(fd);
 	ast_config_destroy(cfg);
-	LOCAL_USER_REMOVE(u);
+	ast_module_user_remove(u);
 	return res;
 
 }
 
-int unload_module(void)
+static int unload_module(void)
 {
 	int res;
 
 	res = ast_unregister_application(app);
 
-	STANDARD_HANGUP_LOCALUSERS;
+	ast_module_user_hangup_all();
 
 	return res;
 }
 
-int load_module(void)
+static int load_module(void)
 {
-	
+	struct ast_config *cfg = ast_config_load(FESTIVAL_CONFIG);
+	if (!cfg) {
+		ast_log(LOG_WARNING, "No such configuration file %s\n", FESTIVAL_CONFIG);
+		return AST_MODULE_LOAD_DECLINE;
+	}
+	ast_config_destroy(cfg);
 	return ast_register_application(app, festival_exec, synopsis, descrip);
 }
 
-char *description(void)
-{
-	return tdesc;
-}
-
-int usecount(void)
-{
-	int res;
-	STANDARD_USECOUNT(res);
-	return res;
-}
-
-char *key()
-{
-	return ASTERISK_GPL_KEY;
-}
+AST_MODULE_INFO_STANDARD(ASTERISK_GPL_KEY, "Simple Festival Interface");
