@@ -31,7 +31,7 @@
 
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 46200 $")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 113507 $")
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -211,7 +211,7 @@ static int parkandannounce_exec(struct ast_channel *chan, void *data)
 	tpl_working = template;
 	tpl_current=strsep(&tpl_working, ":");
 
-	while(tpl_current && looptemp < sizeof(tmp)) {
+	while(tpl_current && looptemp < ARRAY_LEN(tmp)) {
 		tmp[looptemp]=tpl_current;
 		looptemp++;
 		tpl_current=strsep(&tpl_working,":");
