@@ -27,7 +27,7 @@
 
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 40722 $")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 83179 $")
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -95,6 +95,8 @@ static int system_exec_helper(struct ast_channel *chan, void *data, int failmode
 
 	u = ast_module_user_add(chan);
 
+	ast_autoservice_start(chan);
+
 	/* Do our thing here */
 	res = ast_safe_system((char *)data);
 	if ((res < 0) && (errno != ECHILD)) {
@@ -118,6 +120,8 @@ static int system_exec_helper(struct ast_channel *chan, void *data, int failmode
 		res = 0;
 	} 
 
+	ast_autoservice_stop(chan);
+
 	ast_module_user_remove(u);
 
 	return res;
