@@ -17,19 +17,22 @@
  */
 
 /*! \file
+ *
  * \brief App to transmit a URL
+ *
+ * \author Mark Spencer <markster@digium.com>
  * 
  * \ingroup applications
  */
  
+#include "asterisk.h"
+
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 43445 $")
+
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
 
-#include "asterisk.h"
-
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 33480 $")
-
 #include "asterisk/lock.h"
 #include "asterisk/file.h"
 #include "asterisk/logger.h"
@@ -40,8 +43,6 @@ ASTERISK_FILE_VERSION(__FILE__, "$Revision: 33480 $")
 #include "asterisk/image.h"
 #include "asterisk/options.h"
 
-static char *tdesc = "Send URL Applications";
-
 static char *app = "SendURL";
 
 static char *synopsis = "Send a URL";
@@ -52,29 +53,24 @@ static char *descrip =
 "Result is returned in the SENDURLSTATUS channel variable:\n"
 "    SUCCESS       URL successfully sent to client\n"
 "    FAILURE       Failed to send URL\n"
-"    NOLOAD        Clien failed to load URL (wait enabled)\n"
+"    NOLOAD        Client failed to load URL (wait enabled)\n"
 "    UNSUPPORTED   Channel does not support URL transport\n"
 "\n"
 "If the option 'wait' is specified, execution will wait for an\n"
 "acknowledgement that the URL has been loaded before continuing\n"
-"and will return -1 if the peer is unable to load the URL\n"
 "\n"
-"Old behaviour (deprecated): \n"
-" If the client does not support Asterisk \"html\" transport, \n"
-" and there exists a step with priority n + 101, then execution will\n"
-" continue at that step.\n"
-" Otherwise, execution will continue at the next priority level.\n"
-" SendURL only returns 0 if the URL was sent correctly  or if\n"
-" the channel does not support HTML transport, and -1 otherwise.\n";
+"If jumping is specified as an option (the 'j' flag), the client does not\n"
+"support Asterisk \"html\" transport, and there exists a step with priority\n"
+"n + 101, then execution will continue at that step.\n"
+"\n"
+"SendURL continues normally if the URL was sent correctly or if the channel\n"
+"does not support HTML transport.  Otherwise, the channel is hung up.\n";
 
-STANDARD_LOCAL_USER;
-
-LOCAL_USER_DECL;
 
 static int sendurl_exec(struct ast_channel *chan, void *data)
 {
 	int res = 0;
-	struct localuser *u;
+	struct ast_module_user *u;
 	char *tmp;
 	char *options;
 	int local_option_wait=0;
@@ -89,14 +85,9 @@ static int sendurl_exec(struct ast_channel *chan, void *data)
 		return -1;
 	}
 
-	LOCAL_USER_ADD(u);
+	u = ast_module_user_add(chan);
 
 	tmp = ast_strdupa(data);
-	if (!tmp) {
-		ast_log(LOG_ERROR, "Out of memory\n");
-		LOCAL_USER_REMOVE(u);
-		return -1;
-	}
 
 	stringp=tmp;
 	strsep(&stringp, "|");
@@ -108,16 +99,16 @@ static int sendurl_exec(struct ast_channel *chan, void *data)
 	
 	if (!ast_channel_supports_html(chan)) {
 		/* Does not support transport */
-		if (local_option_jump || option_priority_jumping)
+		if (local_option_jump || ast_opt_priority_jumping)
 			 ast_goto_if_exists(chan, chan->context, chan->exten, chan->priority + 101);
 		pbx_builtin_setvar_helper(chan, "SENDURLSTATUS", "UNSUPPORTED");
-		LOCAL_USER_REMOVE(u);
+		ast_module_user_remove(u);
 		return 0;
 	}
 	res = ast_channel_sendurl(chan, tmp);
 	if (res == -1) {
 		pbx_builtin_setvar_helper(chan, "SENDURLSTATUS", "FAILURE");
-		LOCAL_USER_REMOVE(u);
+		ast_module_user_remove(u);
 		return res;
 	}
 	status = "SUCCESS";
@@ -144,7 +135,7 @@ static int sendurl_exec(struct ast_channel *chan, void *data)
 				case AST_HTML_NOSUPPORT:
 					/* Does not support transport */
 					status ="UNSUPPORTED";
-					if (local_option_jump || option_priority_jumping)
+					if (local_option_jump || ast_opt_priority_jumping)
 			 			ast_goto_if_exists(chan, chan->context, chan->exten, chan->priority + 101);
 					res = 0;
 					ast_frfree(f);
@@ -159,39 +150,24 @@ static int sendurl_exec(struct ast_channel *chan, void *data)
 	} 
 out:	
 	pbx_builtin_setvar_helper(chan, "SENDURLSTATUS", status);
-	LOCAL_USER_REMOVE(u);
+	ast_module_user_remove(u);
 	return res;
 }
 
-int unload_module(void)
+static int unload_module(void)
 {
 	int res;
 
 	res = ast_unregister_application(app);
 	
-	STANDARD_HANGUP_LOCALUSERS;
+	ast_module_user_hangup_all();
 
 	return res;	
 }
 
-int load_module(void)
+static int load_module(void)
 {
 	return ast_register_application(app, sendurl_exec, synopsis, descrip);
 }
 
-char *description(void)
-{
-	return tdesc;
-}
-
-int usecount(void)
-{
-	int res;
-	STANDARD_USECOUNT(res);
-	return res;
-}
-
-char *key()
-{
-	return ASTERISK_GPL_KEY;
-}
+AST_MODULE_INFO_STANDARD(ASTERISK_GPL_KEY, "Send URL Applications");
