@@ -31,7 +31,7 @@
 
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 81523 $")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 106235 $")
 
 #include <stdio.h>
 #include <string.h>
@@ -213,21 +213,24 @@ static int phone_indicate(struct ast_channel *chan, int condition, const void *d
 	int res=-1;
 	ast_log(LOG_DEBUG, "Requested indication %d on channel %s\n", condition, chan->name);
 	switch(condition) {
-		case AST_CONTROL_FLASH:
-			ioctl(p->fd, IXJCTL_PSTN_SET_STATE, PSTN_ON_HOOK);
-			usleep(320000);
-			ioctl(p->fd, IXJCTL_PSTN_SET_STATE, PSTN_OFF_HOOK);
+	case AST_CONTROL_FLASH:
+		ioctl(p->fd, IXJCTL_PSTN_SET_STATE, PSTN_ON_HOOK);
+		usleep(320000);
+		ioctl(p->fd, IXJCTL_PSTN_SET_STATE, PSTN_OFF_HOOK);
 			p->lastformat = -1;
 			res = 0;
 			break;
-		case AST_CONTROL_HOLD:
-			ast_moh_start(chan, data, NULL);
-			break;
-		case AST_CONTROL_UNHOLD:
-			ast_moh_stop(chan);
-			break;
-		default:
-			ast_log(LOG_WARNING, "Condition %d is not supported on channel %s\n", condition, chan->name);
+	case AST_CONTROL_HOLD:
+		ast_moh_start(chan, data, NULL);
+		break;
+	case AST_CONTROL_UNHOLD:
+		ast_moh_stop(chan);
+		break;
+	case AST_CONTROL_SRCUPDATE:
+		res = 0;
+		break;
+	default:
+		ast_log(LOG_WARNING, "Condition %d is not supported on channel %s\n", condition, chan->name);
 	}
 	return res;
 }
