@@ -30,7 +30,7 @@
  
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 40722 $")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 90155 $")
 
 #include <unistd.h>
 #include <netinet/in.h>
@@ -76,7 +76,7 @@ struct g726_desc  {
  */
 static int g726_open(struct ast_filestream *tmp, int rate)
 {
-	struct g726_desc *s = (struct g726_desc *)tmp->private;
+	struct g726_desc *s = (struct g726_desc *)tmp->_private;
 	s->rate = rate;
 	if (option_debug)
 		ast_log(LOG_DEBUG, "Created filestream G.726-%dk.\n", 
@@ -131,7 +131,7 @@ static int g726_16_rewrite(struct ast_filestream *s, const char *comment)
 static struct ast_frame *g726_read(struct ast_filestream *s, int *whennext)
 {
 	int res;
-	struct g726_desc *fs = (struct g726_desc *)s->private;
+	struct g726_desc *fs = (struct g726_desc *)s->_private;
 
 	/* Send a frame from the file to the appropriate channel */
 	s->fr.frametype = AST_FRAME_VOICE;
@@ -151,7 +151,7 @@ static struct ast_frame *g726_read(struct ast_filestream *s, int *whennext)
 static int g726_write(struct ast_filestream *s, struct ast_frame *f)
 {
 	int res;
-	struct g726_desc *fs = (struct g726_desc *)s->private;
+	struct g726_desc *fs = (struct g726_desc *)s->_private;
 
 	if (f->frametype != AST_FRAME_VOICE) {
 		ast_log(LOG_WARNING, "Asked to write non-voice frame!\n");
