@@ -26,7 +26,7 @@
  
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 40722 $")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 90155 $")
 
 #include <unistd.h>
 #include <netinet/in.h>
@@ -80,7 +80,7 @@ static struct ast_frame *h263_read(struct ast_filestream *s, int *whennext)
 	int mark;
 	unsigned short len;
 	unsigned int ts;
-	struct h263_desc *fs = (struct h263_desc *)s->private;
+	struct h263_desc *fs = (struct h263_desc *)s->_private;
 
 	/* Send a frame from the file to the appropriate channel */
 	if ((res = fread(&len, 1, sizeof(len), s->f)) < 1)
