@@ -41,9 +41,17 @@ extern "C" {
 #define AST_DEVICE_UNAVAILABLE	5
 /*! Device is ringing */
 #define AST_DEVICE_RINGING	6
+/*! Device is ringing *and* in use */
+#define AST_DEVICE_RINGINUSE	7
+/*! Device is on hold */
+#define AST_DEVICE_ONHOLD	8
 
+/*! \brief Devicestate watcher call back */
 typedef int (*ast_devstate_cb_type)(const char *dev, int state, void *data);
 
+/*!  \brief Devicestate provider call back */
+typedef int (*ast_devstate_prov_cb_type)(const char *data);
+
 /*! \brief Convert device state to text string for output 
  * \param devstate Current device state 
  */
@@ -79,7 +87,7 @@ int ast_device_state_changed(const char *fmt, ...)
 
 
 /*! \brief Tells Asterisk the State for Device is changed 
- * \param device devicename like a dialstrin
+ * \param device devicename like a dialstring
  * Asterisk polls the new extensionstates and calls the registered
  * callbacks for the changed extensions
  * Returns 0 on success, -1 on failure
@@ -93,8 +101,29 @@ int ast_device_state_changed_literal(const char *device);
  * Return -1 on failure, ID on success
  */ 
 int ast_devstate_add(ast_devstate_cb_type callback, void *data);
+
+/*! \brief Unregisters a device state change callback 
+ * \param callback Callback
+ * \param data to pass to callback
+ * The callback is called if the state for extension is changed
+ * Return -1 on failure, ID on success
+ */ 
 void ast_devstate_del(ast_devstate_cb_type callback, void *data);
 
+/*! \brief Add device state provider 
+ * \param label to use in hint, like label:object
+ * \param callback Callback
+ * \retval -1 failure
+ * \retval 0 success
+ */ 
+int ast_devstate_prov_add(const char *label, ast_devstate_prov_cb_type callback);
+
+/*! \brief Remove device state provider 
+ * \param label to use in hint, like label:object
+ * \return nothing
+ */ 
+void ast_devstate_prov_del(const char *label);
+
 int ast_device_state_engine_init(void);
 
 #if defined(__cplusplus) || defined(c_plusplus)
