@@ -132,7 +132,13 @@ struct ast_filestream {
 	FILE *f;
 	struct ast_frame fr;	/* frame produced by read, typically */
 	char *buf;		/* buffer pointed to by ast_frame; */
-	void *private;	/* pointer to private buffer */
+	/* pointer to private buffer */
+	union {
+		void *_private;
+#if !defined(__cplusplus) && !defined(c_plusplus)
+		void *private attribute_deprecated;
+#endif
+	};
 	const char *orig_chan_name;
 };
 
@@ -172,11 +178,16 @@ int ast_streamfile(struct ast_channel *c, const char *filename, const char *pref
 int ast_stream_and_wait(struct ast_channel *chan, const char *file,
 	const char *language, const char *digits);
 
-/*! Stops a stream */
-/*!
+/*! 
+ * \brief Stops a stream 
+ *
  * \param c The channel you wish to stop playback on
+ *
  * Stop playback of a stream 
- * Returns 0 regardless
+ *
+ * \retval 0 always
+ *
+ * \note The channel does not need to be locked before calling this function.
  */
 int ast_stopstream(struct ast_channel *c);
 
