@@ -25,7 +25,7 @@
 
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 89709 $")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 110628 $")
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -215,6 +215,7 @@ int ast_dtmf_stream(struct ast_channel *chan, struct ast_channel *peer, const ch
 {
 	const char *ptr;
 	int res = 0;
+	struct ast_silence_generator *silgen = NULL;
 
 	if (!between)
 		between = 100;
@@ -229,6 +230,10 @@ int ast_dtmf_stream(struct ast_channel *chan, struct ast_channel *peer, const ch
 	if (res < 0)
 		return res;
 
+	if (ast_opt_transmit_silence) {
+		silgen = ast_channel_start_silence_generator(chan);
+	}
+
 	for (ptr = digits; *ptr; ptr++) {
 		if (*ptr == 'w') {
 			/* 'w' -- wait half a second */
@@ -255,6 +260,10 @@ int ast_dtmf_stream(struct ast_channel *chan, struct ast_channel *peer, const ch
 			res = -1;
 	}
 
+	if (silgen) {
+		ast_channel_stop_silence_generator(chan, silgen);
+	}
+
 	return res;
 }
 
@@ -707,7 +716,7 @@ static int __ast_play_and_record(struct ast_channel *chan, const char *playfile,
 	 * message, otherwise we could get a situation where this stream is never
 	 * closed (which would create a resource leak).
 	 */
-	*duration = ast_tellstream(others[0]) / 8000;
+	*duration = others[0] ? ast_tellstream(others[0]) / 8000 : 0;
 
 	if (!prepend) {
 		for (x = 0; x < fmtcnt; x++) {
