@@ -25,7 +25,7 @@
 
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 69805 $")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 114257 $")
 
 #include <time.h>
 #include <string.h>
@@ -305,7 +305,7 @@ int callerid_feed_jp(struct callerid_state *cid, unsigned char *ubuf, int len, i
 		res = fsk_serie(&cid->fskd, buf, &mylen, &b);
 
 		if (mylen < 0) {
-			ast_log(LOG_ERROR, "fsk_serie made mylen < 0 (%d)\n", mylen);
+			ast_log(LOG_ERROR, "No start bit found in fsk data.\n");
 			free(obuf);
 			return -1;
 		}
@@ -561,7 +561,7 @@ int callerid_feed(struct callerid_state *cid, unsigned char *ubuf, int len, int
 		olen = mylen;
 		res = fsk_serie(&cid->fskd, buf, &mylen, &b);
 		if (mylen < 0) {
-			ast_log(LOG_ERROR, "fsk_serie made mylen < 0 (%d)\n", mylen);
+			ast_log(LOG_ERROR, "No start bit found in fsk data.\n");
 			free(obuf);
 			return -1;
 		}
