@@ -27,7 +27,7 @@
 
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 91366 $")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 115333 $")
 
 #include <signal.h>
 #include <stdarg.h>
@@ -875,8 +875,12 @@ void ast_verbose(const char *fmt, ...)
 		ast_localtime(&t, &tm, NULL);
 		strftime(date, sizeof(date), dateformat, &tm);
 		datefmt = alloca(strlen(date) + 3 + strlen(fmt) + 1);
-		sprintf(datefmt, "[%s] %s", date, fmt);
+		sprintf(datefmt, "%c[%s] %s", 127, date, fmt);
 		fmt = datefmt;
+	} else {
+		char *tmp = alloca(strlen(fmt) + 2);
+		sprintf(tmp, "%c%s", 127, fmt);
+		fmt = tmp;
 	}
 
 	if (!(buf = ast_dynamic_str_thread_get(&verbose_buf, VERBOSE_BUF_INIT_SIZE)))
@@ -897,7 +901,7 @@ void ast_verbose(const char *fmt, ...)
 		v->verboser(buf->str);
 	AST_LIST_UNLOCK(&verbosers);
 
-	ast_log(LOG_VERBOSE, "%s", buf->str);
+	ast_log(LOG_VERBOSE, "%s", buf->str + 1);
 }
 
 int ast_register_verbose(void (*v)(const char *string)) 
