@@ -17,7 +17,7 @@
 
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 107352 $")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 116463 $")
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -639,8 +639,7 @@ struct ast_frame *ast_udptl_read(struct ast_udptl *udptl)
 	if (res < 0) {
 		if (errno != EAGAIN)
 			ast_log(LOG_WARNING, "UDPTL read error: %s\n", strerror(errno));
-		if (errno == EBADF)
-			CRASH;
+		ast_assert(errno != EBADF);
 		return &ast_null_frame;
 	}
 
