@@ -25,7 +25,7 @@
 
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 96024 $")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 120371 $")
 
 #include <sys/types.h>
 #include <stdlib.h>
@@ -135,20 +135,23 @@ static int handle_context_dont_include_deprecated(int fd, int argc, char *argv[]
 
 static int handle_context_remove_include(int fd, int argc, char *argv[])
 {
-	if (argc != 6)
+	if (argc != 6) {
 		return RESULT_SHOWUSAGE;
+	}
 
-	if (strcmp(argv[4], "into"))
+	if (strcmp(argv[4], "from")) {
 		return RESULT_SHOWUSAGE;
+	}
 
 	if (!ast_context_remove_include(argv[5], argv[3], registrar)) {
-		ast_cli(fd, "We are not including '%s' into '%s' now\n",
+		ast_cli(fd, "The dialplan no longer includes '%s' into '%s'\n",
 			argv[3], argv[5]);
 		return RESULT_SUCCESS;
 	}
 
 	ast_cli(fd, "Failed to remove '%s' include from '%s' context\n",
 		argv[3], argv[5]);
+
 	return RESULT_FAILURE;
 }
 
@@ -2081,6 +2084,7 @@ static int handle_reload_extensions(int fd, int argc, char *argv[])
 	if (clearglobalvars_config)
 		pbx_builtin_clear_globals();
 	pbx_load_module();
+	ast_cli(fd, "Dialplan reloaded.\n");
 	return RESULT_SUCCESS;
 }
 
