@@ -29,7 +29,7 @@
 
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 107646 $")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 114542 $")
 
 #include <pthread.h>
 #include <stdlib.h>
@@ -1585,22 +1585,35 @@ int ast_bridge_call(struct ast_channel *chan,struct ast_channel *peer,struct ast
 	bridge_cdr = ast_cdr_alloc();
 	if (bridge_cdr) {
 		if (chan->cdr && peer->cdr) { /* both of them? merge */
+			ast_channel_lock(chan);  /* lock the channel before modifing cdrs */
 			ast_cdr_init(bridge_cdr,chan); /* seems more logicaller to use the  destination as a base, but, really, it's random */
 			ast_cdr_start(bridge_cdr); /* now is the time to start */
 
 			/* absorb the channel cdr */
 			ast_cdr_merge(bridge_cdr, chan->cdr);
-			if (!ast_test_flag(chan->cdr, AST_CDR_FLAG_LOCKED))
+			if (!ast_test_flag(chan->cdr, AST_CDR_FLAG_LOCKED)) 
 				ast_cdr_discard(chan->cdr); /* if locked cdrs are in chan, they are taken over in the merge */
+
+			chan->cdr = NULL; /* remove pointer to freed memory before releasing the lock */
+
+			ast_channel_unlock(chan);
 			
 			/* absorb the peer cdr */
+			ast_channel_lock(peer);
 			ast_cdr_merge(bridge_cdr, peer->cdr);
 			if (!ast_test_flag(peer->cdr, AST_CDR_FLAG_LOCKED))
 				ast_cdr_discard(peer->cdr); /* if locked cdrs are in peer, they are taken over in the merge */
 			
 			peer->cdr = NULL;
+			ast_channel_unlock(peer);
+
+			ast_channel_lock(chan);
 			chan->cdr = bridge_cdr; /* make this available to the rest of the world via the chan while the call is in progress */
+			ast_channel_unlock(chan);
+
 		} else if (chan->cdr) {
+
+			ast_channel_lock(chan); /* Lock before modifying CDR */
 			/* take the cdr from the channel - literally */
 			ast_cdr_init(bridge_cdr,chan);
 			/* absorb this data */
@@ -1608,7 +1621,9 @@ int ast_bridge_call(struct ast_channel *chan,struct ast_channel *peer,struct ast
 			if (!ast_test_flag(chan->cdr, AST_CDR_FLAG_LOCKED))
 				ast_cdr_discard(chan->cdr); /* if locked cdrs are in chan, they are taken over in the merge */
 			chan->cdr = bridge_cdr; /* make this available to the rest of the world via the chan while the call is in progress */
+			ast_channel_unlock(chan);
 		} else if (peer->cdr) {
+			ast_channel_lock(peer); /* Lock before modifying CDR */
 			/* take the cdr from the peer - literally */
 			ast_cdr_init(bridge_cdr,peer);
 			/* absorb this data */
@@ -1617,10 +1632,13 @@ int ast_bridge_call(struct ast_channel *chan,struct ast_channel *peer,struct ast
 				ast_cdr_discard(peer->cdr); /* if locked cdrs are in chan, they are taken over in the merge */
 			peer->cdr = NULL;
 			peer->cdr = bridge_cdr; /* make this available to the rest of the world via the chan while the call is in progress */
+			ast_channel_unlock(peer);
 		} else {
+			ast_channel_lock(chan); /* Lock before modifying CDR */
 			/* make up a new cdr */
 			ast_cdr_init(bridge_cdr,chan); /* eh, just pick one of them */
 			chan->cdr = bridge_cdr; /*  */
+			ast_channel_unlock(chan);
 		}
 		if (ast_strlen_zero(bridge_cdr->dstchannel)) {
 			if (strcmp(bridge_cdr->channel, peer->name) != 0)
@@ -1693,7 +1711,7 @@ static void *do_parking_thread(void *ignore)
 					}
 					if (con) {
 						char returnexten[AST_MAX_EXTENSION];
-						snprintf(returnexten, sizeof(returnexten), "%s||t", peername);
+						snprintf(returnexten, sizeof(returnexten), "%s|30|t", peername);
 						ast_add_extension2(con, 1, peername, 1, NULL, NULL, "Dial", strdup(returnexten), ast_free, registrar);
 					}
 					set_c_e_p(chan, parking_con_dial, peername, 1);
